#!/bin/sh

#
#  Copyright (C) 2007 Funambol, Inc.  All rights reserved.
#
#  Before running this script:
#  - set the JAVA_HOME
#  - copy the JDBC driver in the lib directory. It will be automatically loaded.
#
#  Set the JMX_PORT variable below to a different value if the one specified is
#  already in use.
#

JMX_PORT=3101

CURRENT_DIR=$PWD

# Setting OX_LISTENER_HOME
# resolving links - $0 could be a softlink
PRG="$0"
APPNAME=`basename "$PRG"`

while [ -h "$PRG" ]; do
  ls=`ls -ld "$PRG"`
  link=`expr "$ls" : '.*-> \(.*\)$'`
  if expr "$link" : '/.*' > /dev/null; then
    PRG="$link"
  else
    PRG=`dirname "$PRG"`/"$link"
  fi
done

PRGDIR=`dirname "$PRG"`

OX_LISTENER_HOME=`cd "$PRGDIR/.." ; pwd`

BUNDLED_JAVA_HOME=

if [ ! -z "$BUNDLED_JAVA_HOME" ]; then
   JAVA_HOME=$BUNDLED_JAVA_HOME
fi

if [ -z "$JAVA_HOME" ]; then
  echo "Please, set JAVA_HOME before running this script."
  exit 1
fi

if [ ! -f "$JAVA_HOME/bin/java" ]
then
    echo "Please set JAVA_HOME to the path of a valid jre."
    exit;
fi

# Setting classpath
cd $OX_LISTENER_HOME/lib
for jarfile in *.jar; do export CLASSPATH=$CLASSPATH:lib/$jarfile; done
cd ..

JAVA_OPTS="$JAVA_OPTS -Dfile.encoding=UTF-8"
JAVA_OPTS="$JAVA_OPTS -Dfunambol.pushlistener.home=$OX_LISTENER_HOME"
JAVA_OPTS="$JAVA_OPTS -Dfunambol.pushlistener.config.bean=com/funambol/oxlistener/OXListenerConfiguration.xml"
JAVA_OPTS="$JAVA_OPTS -Djava.library.path=$OX_LISTENER_HOME/lib/linux"

JMX_BEAN=com.funambol.oxlistener:type=OXListener

if [ "$1" = "start" ] && [ "$2" = "-debug" -o "$2" = "" ] && [ "$3" = "" ] ; then

  JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote -Dcom.sun.management.jmxremote.port=$JMX_PORT -Dcom.sun.management.jmxremote.ssl=false -Dcom.sun.management.jmxremote.authenticate=false"

  # Uncomment the following line to enable remote debug
  # JAVA_OPTS=$JAVA_OPTS -Xdebug -Xrunjdwp:transport=dt_socket,address=7777,server=y,suspend=n

  echo OX_LISTENER_HOME: $OX_LISTENER_HOME
  echo CLASSPATH: "$CLASSPATH"
  echo JAVA_OPTS: $JAVA_OPTS

  if [ "$2" = "-debug" ] ; then
    "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
    com.funambol.oxlistener.service.OXListener
  else
    "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
    com.funambol.oxlistener.service.OXListener  > /dev/null 2>&1 </dev/zero &
  fi

  cd $CURRENT_DIR

elif [ "$1" = "stop" ] && [ "$2" = "" ] ; then

  echo OX_LISTENER_HOME: $OX_LISTENER_HOME
  echo CLASSPATH: "$CLASSPATH"
  echo JAVA_OPTS: $JAVA_OPTS

  "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
  com.funambol.pushlistener.service.ManagementTools $JMX_BEAN localhost $JMX_PORT stop

  cd $CURRENT_DIR
  
elif [ "$1" = "status" ] && [ "$2" = "" ] ; then

  echo OX_LISTENER_HOME: $OX_LISTENER_HOME
  echo CLASSPATH: "$CLASSPATH"
  echo JAVA_OPTS: $JAVA_OPTS

  "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
  com.funambol.pushlistener.service.ManagementTools $JMX_BEAN localhost $JMX_PORT status

  cd $CURRENT_DIR
  
elif [ "$1" = "license" ] && [ "$2" = "" ] ; then

  less $OX_LISTENER_HOME/LICENSE.txt

  cd $CURRENT_DIR

else

  echo "Usage: $APPNAME command"
  echo "command:"
  echo "  start           Start OX Listener"
  echo "  start -debug    Start OX Listener with output console"
  echo "  stop            Stop OX Listener"
  echo "  status          Show OX Listener status"
  echo "  license         Show the license"
  exit 1

fi
